# Changelog

## [0.0.13a22](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a22) (2023-12-28)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a21...0.0.13a22)

**Merged pull requests:**

- refactor/move\_from\_utils [\#153](https://github.com/OpenVoiceOS/OVOS-workshop/pull/153) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a21](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a21) (2023-12-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a20...0.0.13a21)

**Implemented enhancements:**

- option to remove fallback \(handler\) [\#150](https://github.com/OpenVoiceOS/OVOS-workshop/pull/150) ([emphasize](https://github.com/emphasize))

## [0.0.13a20](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a20) (2023-11-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a19...0.0.13a20)

**Fixed bugs:**

- fix/get\_response\_session [\#149](https://github.com/OpenVoiceOS/OVOS-workshop/pull/149) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a19](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a19) (2023-11-16)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a18...0.0.13a19)

**Fixed bugs:**

- Fix Padatious intent handler registration with multiple native languages [\#148](https://github.com/OpenVoiceOS/OVOS-workshop/pull/148) ([NeonDaniel](https://github.com/NeonDaniel))

## [0.0.13a18](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a18) (2023-11-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a17...0.0.13a18)

**Implemented enhancements:**

- Allows wait argument to be int value for seconds [\#146](https://github.com/OpenVoiceOS/OVOS-workshop/pull/146) ([jaredcobb](https://github.com/jaredcobb))

## [0.0.13a17](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a17) (2023-10-18)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a16...0.0.13a17)

**Implemented enhancements:**

- feat/handle\_hex\_audiodata [\#145](https://github.com/OpenVoiceOS/OVOS-workshop/pull/145) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a16](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a16) (2023-10-13)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a15...0.0.13a16)

**Implemented enhancements:**

- Refactor/converse messages [\#144](https://github.com/OpenVoiceOS/OVOS-workshop/pull/144) ([emphasize](https://github.com/emphasize))

## [0.0.13a15](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a15) (2023-10-10)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a14...0.0.13a15)

**Implemented enhancements:**

- feat/extend\_ovosskill [\#143](https://github.com/OpenVoiceOS/OVOS-workshop/pull/143) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a14](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a14) (2023-10-10)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a13...0.0.13a14)

**Implemented enhancements:**

- Add Russian noise words [\#136](https://github.com/OpenVoiceOS/OVOS-workshop/pull/136) ([putnik](https://github.com/putnik))

## [0.0.13a13](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a13) (2023-10-10)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a12...0.0.13a13)

**Implemented enhancements:**

- CommonQuerySkill handler complete event and tests [\#142](https://github.com/OpenVoiceOS/OVOS-workshop/pull/142) ([NeonDaniel](https://github.com/NeonDaniel))

## [0.0.13a12](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a12) (2023-10-06)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a11...0.0.13a12)

**Fixed bugs:**

- fix mic listen message destination [\#141](https://github.com/OpenVoiceOS/OVOS-workshop/pull/141) ([emphasize](https://github.com/emphasize))

## [0.0.13a11](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a11) (2023-10-03)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a10...0.0.13a11)

**Merged pull requests:**

- unittests/end2end [\#140](https://github.com/OpenVoiceOS/OVOS-workshop/pull/140) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a10](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a10) (2023-10-03)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a9...0.0.13a10)

**Fixed bugs:**

- fix/get\_response\_reprompting [\#139](https://github.com/OpenVoiceOS/OVOS-workshop/pull/139) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a9](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a9) (2023-10-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a8...0.0.13a9)

**Fixed bugs:**

- fix/get\_response\_return\_val [\#138](https://github.com/OpenVoiceOS/OVOS-workshop/pull/138) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a8](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a8) (2023-10-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a7...0.0.13a8)

**Fixed bugs:**

- fix/get\_response\_message\_context [\#137](https://github.com/OpenVoiceOS/OVOS-workshop/pull/137) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a7](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a7) (2023-09-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a6...0.0.13a7)

**Fixed bugs:**

- fix/fallbackV1 [\#135](https://github.com/OpenVoiceOS/OVOS-workshop/pull/135) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a6) (2023-09-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a5...0.0.13a6)

**Merged pull requests:**

- fallback/no\_make\_active [\#134](https://github.com/OpenVoiceOS/OVOS-workshop/pull/134) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a5) (2023-09-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a4...0.0.13a5)

**Implemented enhancements:**

- refactor/get\_response\_v2\_converse\_session [\#68](https://github.com/OpenVoiceOS/OVOS-workshop/pull/68) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a4) (2023-09-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a3...0.0.13a4)

**Merged pull requests:**

- refactor/merge BaseSkill and OVOSSkill [\#133](https://github.com/OpenVoiceOS/OVOS-workshop/pull/133) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a3) (2023-09-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a2...0.0.13a3)

**Implemented enhancements:**

- feat/compat\_handler\_decorator [\#131](https://github.com/OpenVoiceOS/OVOS-workshop/pull/131) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a2) (2023-09-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a1...0.0.13a2)

**Implemented enhancements:**

- feat/sounds\_playback in ovos-audio [\#129](https://github.com/OpenVoiceOS/OVOS-workshop/pull/129) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a1) (2023-09-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.12...0.0.13a1)

**Breaking changes:**

- MessageBusClient compat [\#60](https://github.com/OpenVoiceOS/OVOS-workshop/issues/60)

**Fixed bugs:**

- fix/abstract app init [\#130](https://github.com/OpenVoiceOS/OVOS-workshop/pull/130) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
